==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/guardduty_detector/GuarddutyDetectorDatasourcesMalwareProtection.java <==
package com.hashicorp.cdktf.providers.aws.guardduty_detector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.156Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtection")
@software.amazon.jsii.Jsii.Proxy(GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GuarddutyDetectorDatasourcesMalwareProtection extends software.amazon.jsii.JsiiSerializable {

    /**
     * scan_ec2_instance_with_findings block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#scan_ec2_instance_with_findings GuarddutyDetector#scan_ec2_instance_with_findings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings getScanEc2InstanceWithFindings();

    /**
     * @return a {@link Builder} of {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GuarddutyDetectorDatasourcesMalwareProtection> {
        com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings;

        /**
         * Sets the value of {@link GuarddutyDetectorDatasourcesMalwareProtection#getScanEc2InstanceWithFindings}
         * @param scanEc2InstanceWithFindings scan_ec2_instance_with_findings block. This parameter is required.
         *                                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#scan_ec2_instance_with_findings GuarddutyDetector#scan_ec2_instance_with_findings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder scanEc2InstanceWithFindings(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings) {
            this.scanEc2InstanceWithFindings = scanEc2InstanceWithFindings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GuarddutyDetectorDatasourcesMalwareProtection}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GuarddutyDetectorDatasourcesMalwareProtection build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GuarddutyDetectorDatasourcesMalwareProtection {
        private final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.scanEc2InstanceWithFindings = software.amazon.jsii.Kernel.get(this, "scanEc2InstanceWithFindings", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.scanEc2InstanceWithFindings = java.util.Objects.requireNonNull(builder.scanEc2InstanceWithFindings, "scanEc2InstanceWithFindings is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings getScanEc2InstanceWithFindings() {
            return this.scanEc2InstanceWithFindings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("scanEc2InstanceWithFindings", om.valueToTree(this.getScanEc2InstanceWithFindings()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtection"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy that = (GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy) o;

            return this.scanEc2InstanceWithFindings.equals(that.scanEc2InstanceWithFindings);
        }

        @Override
        public final int hashCode() {
            int result = this.scanEc2InstanceWithFindings.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/guardduty_detector/GuarddutyDetectorDatasourcesMalwareProtection.java <==
package com.hashicorp.cdktf.providers.aws.guardduty_detector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.009Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtection")
@software.amazon.jsii.Jsii.Proxy(GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GuarddutyDetectorDatasourcesMalwareProtection extends software.amazon.jsii.JsiiSerializable {

    /**
     * scan_ec2_instance_with_findings block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/guardduty_detector#scan_ec2_instance_with_findings GuarddutyDetector#scan_ec2_instance_with_findings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings getScanEc2InstanceWithFindings();

    /**
     * @return a {@link Builder} of {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GuarddutyDetectorDatasourcesMalwareProtection> {
        com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings;

        /**
         * Sets the value of {@link GuarddutyDetectorDatasourcesMalwareProtection#getScanEc2InstanceWithFindings}
         * @param scanEc2InstanceWithFindings scan_ec2_instance_with_findings block. This parameter is required.
         *                                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/guardduty_detector#scan_ec2_instance_with_findings GuarddutyDetector#scan_ec2_instance_with_findings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder scanEc2InstanceWithFindings(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings) {
            this.scanEc2InstanceWithFindings = scanEc2InstanceWithFindings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GuarddutyDetectorDatasourcesMalwareProtection}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GuarddutyDetectorDatasourcesMalwareProtection build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GuarddutyDetectorDatasourcesMalwareProtection}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GuarddutyDetectorDatasourcesMalwareProtection {
        private final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings scanEc2InstanceWithFindings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.scanEc2InstanceWithFindings = software.amazon.jsii.Kernel.get(this, "scanEc2InstanceWithFindings", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.scanEc2InstanceWithFindings = java.util.Objects.requireNonNull(builder.scanEc2InstanceWithFindings, "scanEc2InstanceWithFindings is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings getScanEc2InstanceWithFindings() {
            return this.scanEc2InstanceWithFindings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("scanEc2InstanceWithFindings", om.valueToTree(this.getScanEc2InstanceWithFindings()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtection"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy that = (GuarddutyDetectorDatasourcesMalwareProtection.Jsii$Proxy) o;

            return this.scanEc2InstanceWithFindings.equals(that.scanEc2InstanceWithFindings);
        }

        @Override
        public final int hashCode() {
            int result = this.scanEc2InstanceWithFindings.hashCode();
            return result;
        }
    }
}
